@@ -1,6 +1,6 @@
 # -*- coding:utf-8 -*-
-from .timezonefinder import TimezoneFinder, TimezoneFinderL
+from timezonefinder.timezonefinder import TimezoneFinder, TimezoneFinderL
 
 # https://docs.python.org/3/tutorial/modules.html#importing-from-a-package
 # determines which objects will be imported with "import *"
-__all__ = ('TimezoneFinder', 'TimezoneFinderL')
+__all__ = ("TimezoneFinder", "TimezoneFinderL")
